@@ -1,17 +1,48 @@
+from django.contrib.auth import get_user_model
 from django.test import TestCase
 from django.urls import reverse
+from swapper import load_model
 
 from openwisp_users.tests.utils import TestOrganizationMixin
 
 from ...tests.utils import TestAdminMixin
-from ..models import Template
-from . import CreateConfigTemplateMixin
+from .utils import CreateConfigTemplateMixin
+
+Template = load_model('config', 'Template')
+User = get_user_model()
 
 
-class TestTemplate(
+class TestViews(
     CreateConfigTemplateMixin, TestAdminMixin, TestOrganizationMixin, TestCase
 ):
-    template_model = Template
+    """
+    tests for config.views
+    """
+
+    def setUp(self):
+        User.objects.create_superuser(
+            username='admin', password='tester', email='admin@admin.com'
+        )
+
+    def test_schema_403(self):
+        response = self.client.get(reverse('config:schema'))
+        self.assertEqual(response.status_code, 403)
+        self.assertIn('error', response.json())
+
+    def test_schema_200(self):
+        self.client.force_login(User.objects.get(username='admin'))
+        response = self.client.get(reverse('config:schema'))
+        self.assertEqual(response.status_code, 200)
+        self.assertIn('netjsonconfig.OpenWrt', response.json())
+
+    def test_schema_hostname_hidden(self):
+        from ..views import available_schemas
+
+        for key, schema in available_schemas.items():
+            if 'general' not in schema['properties']:
+                continue
+            if 'hostname' in schema['properties']['general']['properties']:
+                self.fail('hostname property must be hidden')
 
     def _create_template_test_data(self):
         org1 = self._create_org(name='org1')
